import setuptools

setuptools.setup(
    name="tenlineeda",
    version="0.0.3",
    author="may_b_prince",
    author_email="princekminati@gmail.com",
    description="I'm tring to making EDA a bit faster for data scientist",
    long_description="This Library has only one function called <summery>, it will generate your EDA and tells you where you have to dig deeper",
    packages=setuptools.find_packages(),
    
)